@@ -665,6 +665,7 @@ def S_tot(sim, Sigma=None):
     -------
     Stot : Field
         Total source terms of surface density"""
+    Sext = sim.dust.S.ext
     if Sigma is None:
         Sigma = sim.dust.Sigma
         Scoag = sim.dust.S.coag
@@ -676,7 +677,7 @@ def S_tot(sim, Sigma=None):
         Shyd = sim.dust.S.hyd.updater.beat(sim, Sigma=Sigma)
         if Shyd is None:
             Shyd = sim.dust.S.hyd
-    return Scoag + Shyd
+    return Scoag + Shyd + Sext
 
 
 def Sigma_deriv(sim, t, Sigma):
@@ -733,7 +734,7 @@ def St_Epstein_StokesI(sim):
 
 def coagulation_parameters(sim):
     """Function calculates the coagulation parameters needed for a simple
-    sticking-cratering-fragmentation collision model. The sticking matrix
+    sticking-erosion-fragmentation collision model. The sticking matrix
     is calculated with the method described in appendices A.1. and A.2. of
     Brauer et al. (2008).
 
@@ -756,7 +757,7 @@ def coagulation_parameters(sim):
     only the non-zero elemts are stored in ``cstick`` of shape ``(4, Nm, Nm)``.
     The positions of the non-zero elements along the first axis are stored
     in ``cstick_ind``. For details see Brauer et al. (2008)."""
-    cstick, cstick_ind, A, eps, klf, krm, phi = dust_f.coagulation_parameters(sim.ini.dust.crateringMassRatio,
+    cstick, cstick_ind, A, eps, klf, krm, phi = dust_f.coagulation_parameters(sim.ini.dust.erosionMassRatio,
                                                                               sim.ini.dust.excavatedMass,
                                                                               sim.ini.dust.fragmentDistribution,
                                                                               sim.grid.m,
